/***************************************************************************
 *   copyright            : (C) 1999 by Daniel Reith                       *
 *   email                : DanR@gmx.de                                    *
 *                                                                         *
 *   copyright           : (C) 2003 by Hendrik Sattler                     *
 *   mail                : pingos@hendrik-sattler.de                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OPTIONEN_H
#define OPTIONEN_H

#include "wx/wx.h"

class ODialog: public wxDialog {
 public:
  ODialog(wxWindow* parent);
  ~ODialog();
  
  void OnOK(wxCommandEvent* event);
  
 private:
  wxStaticText descr1;
  wxComboBox* selection1;
  wxStaticText descr2;
  wxComboBox* selection2;
  wxButton btnSave;
  wxButton btnCancel;
  
  DECLARE_EVENT_TABLE()
};

#endif
